pub trait JsonCastable<T> { }Expand description
Marker trait for restricting the types Raw::deserialize_as, Raw::cast and
Raw::cast_ref can be called with.
Implementing this trait for a type U means that it is safe to cast from U to T because T
can be deserialized from the same JSON as U.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".